
# Slot: slots


slot definitions

URI: [linkml:slot_definitions](https://w3id.org/linkml/slot_definitions)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
